@@ -14,12 +14,15 @@ _last_checked_access_token = None
 def _verify_access_token(access_token):
     try:
         claims = decode_token(access_token)
+
+        if not "iat" in claims or int(claims["iat"]) > datetime.datetime.utcnow().timestamp():
+            raise Exception("Access token is not yet valid.")
+
+        if not "exp" in claims or int(claims["exp"]) < datetime.datetime.utcnow().timestamp():
+            raise Exception("Access token has expired and is no longer valid.")
     except:
         raise Exception("Access token is not valid. Please double-check value and try again.")
 
-    if not "exp" in claims or claims["exp"] < datetime.datetime.utcnow().timestamp():
-        raise Exception("Access token has expired and is no longer valid.")
-
     global _last_checked_access_token
     _last_checked_access_token = access_token
 
